Card

Struct Card 

pub struct Card { /* private fields */ }
This struct represents a smartcard.

Implementations

Source

impl Card

pub fn connect_to( context: Arc<Context>, reader: &Reader, share_mode: ShareMode, preferred_protocol: Protocol, ) -> Result<Card>

Connect to a smartcard on the specified reader

Arguments
  • context - The resource manager context.
  • reader - The reader that contains the smartcard you want to connect to.
  • share_mode - How do you want to share the access to the smartcard.
  • preferred_protocol - What protocol do you want to use to connect to the smartcard.
pub fn get_pci(&self) -> Result<&SCARD_IO_REQUEST>

Get a pointer to the static PCI from the specified protocol

pub fn reconnect(&mut self, init_type: InitializationType) -> Result<()>

Reconnect to the smartcard

Arguments
  • init_type - How to reset the card.
pub fn send_raw_command( &self, cmd: &[u8], max_answer_size: usize, ) -> Result<Vec<u8>>

Send a raw command to the smartcard.

Arguments
  • cmd - The cmd you want to send.
  • max_answer_size - The maximum size of the expected answer.